#include "firmwarefile.h"

FirmwareFile::FirmwareFile(QString file_path)
{
	uff = uff_alloc();
	path = file_path;
	dirty = false;
	valid = false;
	loadData();
}

FirmwareFile::FirmwareFile()
{
	uff = uff_alloc();
	path = "";
	dirty = true;
	valid = false;
}

FirmwareFile::~FirmwareFile()
{
	uff_free(uff);
}

void FirmwareFile::loadData()
{
	int ret;

	valid = false;
	if (path.isNull() || path.isEmpty())
		return;

	ret = uff_load(uff, path.toLocal8Bit());
	if (!ret)
		valid = true;
}

bool FirmwareFile::reload()
{
	loadData();
	if (valid)
		dirty = false;
	return valid;
}

bool FirmwareFile::reload(QString file_path)
{
	path = file_path;
	return reload();
}

bool FirmwareFile::save()
{
	int ret;

	ret = uff_store(uff, path.toLocal8Bit());
	if (ret)
		return false;
	return true;
}

bool FirmwareFile::save(QString file_path)
{
	path = file_path;
	return save();
}

void FirmwareFile::setPath(QString file_path)
{
	path = file_path;
	dirty = true;
}

void FirmwareFile::setSerialNumber(uint32_t number)
{
	uff_set_serial(uff, number);
	dirty = true;
}

void FirmwareFile::setPublicKey(firmware_ssh_key key)
{
	uff_section_write(uff, UFF_SECTION_SSH_PUBLIC_KEY,
			key.bytes, key.length);
	dirty = true;
}

void FirmwareFile::setPrivateKey(firmware_ssh_key key)
{
	uff_section_write(uff, UFF_SECTION_SSH_PRIVATE_KEY,
			key.bytes, key.length);
	dirty = true;
}

void FirmwareFile::setFirmware(firmware_data data)
{
	uff_section_write(uff, UFF_SECTION_FIRMWARE,
			data.bytes, data.length);
	dirty = true;
}

QString FirmwareFile::getPath()
{
	return path;
}

uint32_t FirmwareFile::getSerialNumber()
{
	return uff_get_serial(uff);
}

firmware_ssh_key FirmwareFile::getPublicKey()
{
	firmware_ssh_key key;

	key.length = uff_section_size(uff, UFF_SECTION_SSH_PUBLIC_KEY);
	key.bytes = (char *) uff_section_map(uff, UFF_SECTION_SSH_PUBLIC_KEY);
	return key;
}

firmware_ssh_key FirmwareFile::getPrivateKey()
{
	firmware_ssh_key key;

	key.length = uff_section_size(uff, UFF_SECTION_SSH_PRIVATE_KEY);
	key.bytes = (char *) uff_section_map(uff, UFF_SECTION_SSH_PRIVATE_KEY);
	return key;
}

bool FirmwareFile::isValid()
{
	return valid;
}

bool FirmwareFile::loadPublicKeyFromFile(QString file_path)
{
	int ret;

	ret = uff_section_from_file(uff, UFF_SECTION_SSH_PUBLIC_KEY,
			file_path.toLocal8Bit());
	return ret ? false : true;
}

bool FirmwareFile::loadPrivateKeyFromFile(QString file_path)
{
	int ret;

	ret = uff_section_from_file(uff, UFF_SECTION_SSH_PRIVATE_KEY,
			file_path.toLocal8Bit());
	return ret ? false : true;
}

bool FirmwareFile::loadFirmwareFromFile(QString file_path)
{
	int ret;

	ret = uff_section_from_file(uff, UFF_SECTION_FIRMWARE,
			file_path.toLocal8Bit());
	return ret ? false : true;
}
