#ifndef __FIRMWAREFILE_H__
#define __FIRMWAREFILE_H__

#include <QString>
#include <QFile>
#include <QIODevice>
#include <QDataStream>
#include <stdint.h>
#include <stdlib.h>

#include <uff.h>

struct firmware_ssh_key {
	char *bytes;
	uint64_t length;
};

struct firmware_data {
	char *bytes;
	uint64_t length;
};

class FirmwareFile {
private:
	QString path;
	uff_t uff;
	bool valid;		/* true if loaded successfully */
	bool dirty;		/* altered by user */
	void loadData();
public:
	FirmwareFile(QString file_path);
	FirmwareFile();
	~FirmwareFile();

	bool reload();
	bool reload(QString file_path);
	bool save();
	bool save(QString file_path);
	bool isValid();
	bool loadPrivateKeyFromFile(QString file_path);
	bool loadPublicKeyFromFile(QString file_path);
	bool loadFirmwareFromFile(QString file_path);

	void setPath(QString file_path);
	void setSerialNumber(uint32_t number);
	void setPublicKey(firmware_ssh_key key);
	void setPrivateKey(firmware_ssh_key key);
	void setFirmware(firmware_data data);

	QString getPath();
	uint32_t getSerialNumber();
	firmware_ssh_key getPublicKey();
	firmware_ssh_key getPrivateKey();
};

#endif
