#ifndef __SSHTHREAD_H__
#define __SSHTHREAD_H__

#include <QtCore>
#include <QRegExp>
#include <QTimer>
#include <libssh/libssh.h>
#include <stdlib.h>

#define SSHD_PORT 22
#define USER_NAME "wug"
#define SSHTHREAD_TIMEOUT 120

enum validation_status {
	SUCCESS,
	CONNECTION_FAILED,
	PUBLIC_KEY_FAILED,
	PRIVATE_KEY_FAILED,
	AUTH_FAILED,
	AUTH_PARTIAL,
	UNKNOWN_ERROR,
	NOT_STARTED,
	INIT_FAILED,
	CHANNEL_INIT_FAIL,
	SESSION_INIT_FAIL,
	COMMAND_ERROR,
	STREAM_ERROR,
	PARSE_ERROR,
	CHENNEL_END,
	SESSION_TIMEOUT,
	SERIAL_MISMATCH,
	FIRMWARE_CORRUPTED
};

class SshThread : public QThread {
	Q_OBJECT

	private:
		QString public_key_path;
		QString private_key_path;
		QString remote_host;
		int remote_host_port;
		enum validation_status validation_status;
		unsigned long serial_number;
		ssh_session session;
		ssh_channel channel;
		void closeChannel();

	protected:
		void run();

	public:
		SshThread(QString public_key_file, QString private_key_file,
					QString host, int port,
					unsigned long serial);
		~SshThread();
		bool getFirmwareValid();
		enum validation_status getValidationStatus();
	signals:
		void verProgress(int);
		void verStatus(QString);
};

#endif
