/*
 * uff-utils - uff.h
 *
 * UFF file format description
 *
 * Copyright (C) 2010  Krzysztof Mazur <krzysiek@podlesie.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Fundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __UFF_H
#define __UFF_H

#include <stddef.h>
#include <stdio.h>
#include <sys/types.h>

enum {
	UFF_SECTION_SSH_PUBLIC_KEY,
	UFF_SECTION_SSH_PRIVATE_KEY,
	UFF_SECTION_FIRMWARE,
	UFF_SECTION_MAX,
};

struct uff;
typedef struct uff *uff_t;

#define UFF_INTERFACE_VERSION 0x000000

#ifdef __cplusplus
extern "C" {
#endif

void __uff_library_init(unsigned int version);
#define uff_library_init __uff_library_init(UFF_INTERFACE_VERSION);

uff_t uff_alloc(void);
int uff_init(uff_t uff);
void uff_destroy(uff_t uff);
void uff_free(uff_t uff);

int uff_load(uff_t uff, const char *file);
int uff_store(uff_t uff, const char *file);
int uff_load_f(uff_t uff, FILE *f);
int uff_store_f(uff_t uff, FILE *f);

unsigned long uff_get_serial(uff_t uff);
int uff_set_serial(uff_t uff, unsigned long serial);

size_t uff_section_size(uff_t uff, unsigned int section);
void *uff_section_map(uff_t uff, unsigned int section);
ssize_t uff_section_read(uff_t uff, unsigned int section, void *buf,
		size_t count);
ssize_t uff_section_write(uff_t uff, unsigned int section, void *buf,
		size_t count);

int uff_section_from_file(uff_t uff, unsigned int section, const char *fname);
int uff_section_to_file(uff_t uff, unsigned int section, const char *fname);

#ifdef __cplusplus
}
#endif

#endif
